#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 syb
version:              0.7.3
visibility:           public
id:                   syb-0.7.3-LrvXJMjYPlcHf68JytS4Q
key:                  syb-0.7.3-LrvXJMjYPlcHf68JytS4Q
license:              BSD-3-Clause
maintainer:           Sergey Vinokurov <serg.foo@gmail.com>
author:               Ralf Lammel, Simon Peyton Jones, Jose Pedro Magalhaes
stability:            provisional
homepage:             https://github.com/dreixel/syb
synopsis:             Scrap Your Boilerplate
description:
    This package contains the generics system described in the
    /Scrap Your Boilerplate/ papers (see
    <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
    It defines the @Data@ class of types permitting folding and unfolding
    of constructor applications, instances of this class for primitive
    types, and a variety of traversals.

category:             Generics
abi:                  5afa9990aeab7883d15a84cf15b7b4e4
exposed:              True
exposed-modules:
    Data.Generics Data.Generics.Aliases Data.Generics.Basics
    Data.Generics.Builders Data.Generics.Instances
    Data.Generics.Schemes Data.Generics.Text Data.Generics.Twins
    Generics.SYB Generics.SYB.Aliases Generics.SYB.Basics
    Generics.SYB.Builders Generics.SYB.Instances Generics.SYB.Schemes
    Generics.SYB.Text Generics.SYB.Twins

import-dirs:          /usr/lib/ghc-9.6.6/site-local/syb-0.7.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/syb-0.7.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/syb-0.7.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-syb
hs-libraries:         HSsyb-0.7.3-LrvXJMjYPlcHf68JytS4Q
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-syb/html/syb.haddock
haddock-html:         /usr/share/doc/haskell-syb/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

